#!/bin/bash

# Usage: sudo ./DEFCON_China_Programmer.sh

readonly FILENAME="/home/pi/Desktop/DEFCON_China_Badge_2019.ino.eightanaloginputs.hex"

sleep 5
echo
echo -e "\e[1;97mWelcome to the DEF CON China 1.0 Badge Programming Station"
echo

while true; do
	echo -e -n "\e[0;32m[*] \e[39mConnect New Board to USB..."
	
	# Wait until a new FT231X enumerates a serial port
	until [ -e /dev/ttyUSB0 ] ; do
		:
	done
	echo "Done!"
	
	echo -e "\e[0;32m[*] \e[39mFT231X Detected w/ Serial Number: $(/home/pi/Desktop/FTDI/ftx_prog --dump | grep "Serial Number =" | tail -c 9)"

	# Configure the FT231X, using the previous serial number, with the first two characters changed to 'DC'
	until /home/pi/Desktop/FTDI/ftx_prog --cbus 0 PWREN --cbus 1 PWREN --cbus 2 TxRxLED --cbus 3 BCD_Charger# --manufacturer "Grand Idea Studio" --product "DEF CON China 1.0" --new-serial-number DC$(/home/pi/Desktop/FTDI/ftx_prog --dump | grep "Serial Number =" | tail -c 7) --max-bus-power 250 --self-powered off --remote-wakeup on --suspend-pull-down off --bcd-enable on --force_power_enable on --load-vcp on > /dev/null ; do
		:
	done
	# If there's a failure, keep trying
	echo -e "\e[0;32m[*] \e[39mFT231X Configured w/ Revised Serial Number: $(/home/pi/Desktop/FTDI/ftx_prog --dump | grep "Serial Number =" | tail -c 9)"

    echo -e -n "\e[0;32m[*] \e[39mRe-Enumerating..."
	# Disable then re-enable USB ports, to force the FT231X to re-enumerate, with the new CBUS settings
	echo 0 > /sys/bus/usb/devices/usb1/authorized
	sleep 1
	echo 1 > /sys/bus/usb/devices/usb1/authorized
	# Wait until a new FT231X enumerates a serial port
	until [ -e /dev/ttyUSB0 ] ; do
		:
	done
	echo "Done!"

	# Load badge firmware onto board
	echo -e "\e[0;32m[*] \e[39mLoading Arduino Code: $FILENAME"
	if avrdude -C/opt/arduino-1.8.9/hardware/tools/avr/etc/avrdude.conf -patmega328p -carduino -P/dev/ttyUSB0 -b57600 -D -Uflash:w:$FILENAME:i ; then
		echo -e "\e[1;32m>>>>>>>>>> OK <<<<<<<<<<"
	else
		echo -e "\e[1;31m>>>>>>>>>> ERROR <<<<<<<<<<"
	fi

	echo
    echo -e -n "\e[0;32m[*] \e[39mCarefully Remove Board from USB..."
	# Wait for removal of the FT231X
	while [ -e /dev/ttyUSB0 ] ; do
		:
	done
	
	echo "Done!"
	echo
done
